/**
 * Copyright (c) 2015, Intel Corporation
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Intel Corporation nor the names of its contributors
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.intel.stl.ui.monitor;


public class TreeSubpageSelection {
    private final TreeSelection treeSelection;

    private final String subpageName;

    /**
     * Description:
     * 
     * @param treeSelection
     * @param subpageName
     */
    public TreeSubpageSelection(TreeSelection treeSelection, String subpageName) {
        super();
        this.treeSelection = treeSelection;
        this.subpageName = subpageName;
    }

    /**
     * @return the treeSelection
     */
    public TreeSelection getTreeSelection() {
        return treeSelection;
    }

    /**
     * @return the subpageName
     */
    public String getSubpageName() {
        return subpageName;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result =
                prime * result
                        + ((subpageName == null) ? 0 : subpageName.hashCode());
        result =
                prime
                        * result
                        + ((treeSelection == null) ? 0 : treeSelection
                                .hashCode());
        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        TreeSubpageSelection other = (TreeSubpageSelection) obj;
        if (subpageName == null) {
            if (other.subpageName != null) {
                return false;
            }
        } else if (!subpageName.equals(other.subpageName)) {
            return false;
        }
        if (treeSelection == null) {
            if (other.treeSelection != null) {
                return false;
            }
        } else if (!treeSelection.equals(other.treeSelection)) {
            return false;
        }
        return true;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return "TreeSubpageSelection [treeSelection=" + treeSelection
                + ", subpageName=" + subpageName + "]";
    }
}
